@@ -184,8 +184,7 @@ class Page(pyscp.core.Page):
     def source(self):
         data = self._module('viewsource/ViewSourceModule')['body']
         soup = bs4.BeautifulSoup(data, 'lxml')
-        source = ''.join([s + '\n' for s in soup.text.replace('\t','').split('\n')[1:]][1:])
-        return 
+        return ''.join([s + '\n' for s in soup.text.replace('\t','').split('\n')[1:]][1:])
 
     @property
     def created(self):
@@ -224,24 +223,27 @@ class Page(pyscp.core.Page):
 
     def edit(self, source, title=None, comment=None):
         """Overwrite the page with the new source and title."""
-        if title is None:
-            title = self._raw_title
-        self._flush('html', 'history', 'source')
-        wiki_page = self.url.split('/')[-1]
-        lock = self._module(
-            'edit/PageEditModule',
-            mode='page',
-            wiki_page=wiki_page,
-            force_lock=True)
-        return self._action(
-            'savePage',
-            source=source,
-            title=title,
-            comments=comment,
-            wiki_page=wiki_page,
-            lock_id=lock['lock_id'],
-            lock_secret=lock['lock_secret'],
-            revision_id=lock.get('page_revision_id', None))
+        try:
+            if title is None:
+                title = self._raw_title
+            self._flush('html', 'history', 'source')
+            wiki_page = self.url.split('/')[-1]
+            lock = self._module(
+                'edit/PageEditModule',
+                mode='page',
+                wiki_page=wiki_page,
+                force_lock=True)
+            return self._action(
+                'savePage',
+                source=source,
+                title=title,
+                comments=comment,
+                wiki_page=wiki_page,
+                lock_id=lock['lock_id'],
+                lock_secret=lock['lock_secret'],
+                revision_id=lock.get('page_revision_id', None))
+        except:
+            self.create(source,title,comment)
 
     def create(self, source, title, comment=None):
         if not hasattr(self, '_cache'):
@@ -258,7 +260,7 @@ class Page(pyscp.core.Page):
 
     def set_tags(self, tags):
         """Replace the tags of the page."""
-        res = self._action('saveTags', tags=''.join(tags))
+        res = self._action('saveTags', tags=' '.join(tags))
         self._flush('history', '_pdata')
         return res
 
@@ -586,7 +588,7 @@ class User(pyscp.core.User):
         return '{}.{}({})'.format(
             self.__module__,
             self.__class__.__name__,
-            repr(self.user))
+            repr(self.username))
     
     ###########################################################################
     # Internal Methods
